Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1840)

Unified Diff: content/child/resource_dispatcher.cc

Issue 1181493002: [Patch 3 of 6] Split out content/child's SiteIsolationPolicy into two new classes. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@rename_policy_to_sniffer2
Patch Set: Yet more comment fixes. Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/child/resource_dispatcher.cc
diff --git a/content/child/resource_dispatcher.cc b/content/child/resource_dispatcher.cc
index ba3c13ccd2a6a114b9bcfc60ee3b73a20a4fe46b..7c63a4ced8da6a669b61143f9c5d69e1721e3074 100644
--- a/content/child/resource_dispatcher.cc
+++ b/content/child/resource_dispatcher.cc
@@ -161,11 +161,10 @@ void ResourceDispatcher::OnReceivedResponse(
ResourceResponseInfo renderer_response_info;
ToResourceResponseInfo(*request_info, response_head, &renderer_response_info);
request_info->site_isolation_metadata =
- SiteIsolationPolicy::OnReceivedResponse(request_info->frame_origin,
- request_info->response_url,
- request_info->resource_type,
- request_info->origin_pid,
- renderer_response_info);
+ SiteIsolationStatsGatherer::OnReceivedResponse(
+ request_info->frame_origin, request_info->response_url,
+ request_info->resource_type, request_info->origin_pid,
+ renderer_response_info);
request_info->peer->OnReceivedResponse(renderer_response_info);
}
@@ -241,7 +240,7 @@ void ResourceDispatcher::OnReceivedData(int request_id,
// Check whether this response data is compliant with our cross-site
// document blocking policy. We only do this for the first chunk of data.
if (request_info->site_isolation_metadata.get()) {
- SiteIsolationPolicy::OnReceivedFirstChunk(
+ SiteIsolationStatsGatherer::OnReceivedFirstChunk(
request_info->site_isolation_metadata, data_ptr, data_length);
request_info->site_isolation_metadata.reset();
}
@@ -302,7 +301,7 @@ void ResourceDispatcher::OnReceivedRedirect(
if (!request_info)
return;
// We update the response_url here so that we can send it to
// SiteIsolationPolicy later when OnReceivedResponse is called.
request_info->response_url = redirect_info.new_url;
request_info->pending_redirect_message.reset(
new ResourceHostMsg_FollowRedirect(request_id));
@@ -302,7 +301,7 @@ void ResourceDispatcher::OnReceivedRedirect(
return;
// We update the response_url here so that we can send it to
- // SiteIsolationPolicy later when OnReceivedResponse is called.
+ // SiteIsolationStatsGatherer later when OnReceivedResponse is called.
request_info->response_url = redirect_info.new_url;
request_info->pending_redirect_message.reset(

Powered by Google App Engine
This is Rietveld 408576698